mirror of
https://gitlab.com/libeigen/eigen.git
synced 2026-04-10 11:34:33 +08:00
Fix CUDA clang again with new C++11 usages
This commit is contained in:
@@ -1220,7 +1220,7 @@ struct TensorEvaluator<const TensorContractionOp<Indices, LeftArgType, RightArgT
|
||||
typedef typename PacketType<CoeffReturnType, GpuDevice>::type PacketReturnType;
|
||||
|
||||
enum {
|
||||
Layout = TensorEvaluator<LeftArgType, Device>::Layout,
|
||||
Layout = TensorEvaluator<LeftArgType, Device>::Layout
|
||||
};
|
||||
|
||||
// Most of the code is assuming that both input tensors are ColMajor. If the
|
||||
|
||||
@@ -606,7 +606,7 @@ __global__ void EigenConvolutionKernel1D(
|
||||
}
|
||||
__syncthreads();
|
||||
}
|
||||
};
|
||||
}
|
||||
|
||||
template <typename InputEvaluator, typename Index, typename InputDims,
|
||||
int StaticKernelSizeX, int StaticKernelSizeY>
|
||||
@@ -674,7 +674,7 @@ __global__ void EigenConvolutionKernel2D(
|
||||
|
||||
__syncthreads();
|
||||
}
|
||||
};
|
||||
}
|
||||
|
||||
template <typename InputEvaluator, typename Index, typename InputDims>
|
||||
__global__ void EigenConvolutionKernel3D(
|
||||
@@ -740,9 +740,7 @@ __global__ void EigenConvolutionKernel3D(
|
||||
}
|
||||
__syncthreads();
|
||||
}
|
||||
};
|
||||
|
||||
|
||||
}
|
||||
|
||||
template<typename Indices, typename InputArgType, typename KernelArgType>
|
||||
struct TensorEvaluator<const TensorConvolutionOp<Indices, InputArgType, KernelArgType>, GpuDevice>
|
||||
|
||||
@@ -78,7 +78,7 @@ struct PacketType<half, GpuDevice> {
|
||||
HasLog = 1,
|
||||
HasLog1p = 0,
|
||||
HasLog10 = 0,
|
||||
HasPow = 1,
|
||||
HasPow = 1
|
||||
};
|
||||
};
|
||||
#endif
|
||||
|
||||
Reference in New Issue
Block a user